summaryrefslogtreecommitdiff
path: root/libre/xchat-libre/no-firefox.patch
blob: 60c4846ee9c8463cca26f86fba5b13ee182b9954 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
diff -Nur xchat-2.8.8.orig/src/fe-gtk/fe-gtk.c xchat-2.8.8/src/fe-gtk/fe-gtk.c
--- xchat-2.8.8.orig/src/fe-gtk/fe-gtk.c	2010-05-16 00:15:42.000000000 -0300
+++ xchat-2.8.8/src/fe-gtk/fe-gtk.c		2013-01-19 02:11:00.691529212 -0200
@@ -955,8 +955,10 @@
 			return;
 	}
 
-	/* everything failed, what now? just try firefox */
-	if (try_browser ("firefox", NULL, url))
+	/* everything failed, what now? just try iceweasel or icecat */
+	if (try_browser ("iceweasel", NULL, url))
+		return;
+	if (try_browser ("icecat", NULL, url))
 		return;
 
 	/* fresh out of ideas... */